@@ -5,6 +5,9 @@ use std::fmt::Formatter;
 use std::path::Path;
 
 use img_hash::ImageHash;
+use serde::Deserialize;
+use serde::Serialize;
+use serde::Serializer;
 
 use super::item_traits::Orientation;
 use super::item_traits::PropertyResolver;
@@ -12,7 +15,7 @@ use super::item_traits::PropertyResolver;
 pub type HashType = ImageHash<Vec<u8>>;
 
 /// A single file item with all properties required by image_sieve
-#[derive(Eq, PartialEq, Debug, Clone)]
+#[derive(Eq, PartialEq, Debug, Clone, Serialize, Deserialize)]
 pub struct FileItem {
     /// Actual file path
     path: String,
@@ -27,9 +30,33 @@ pub struct FileItem {
     /// Orientation of the image
     orientation: Option<Orientation>,
     /// Hash of the image
+    #[serde(serialize_with = "serialize_hash")]
+    #[serde(deserialize_with = "deserialize_hash")]
     hash: Option<HashType>,
 }
 
+pub fn serialize_hash<S>(hash: &Option<HashType>, s: S) -> Result<S::Ok, S::Error>
+where
+    S: Serializer,
+{
+    match hash {
+        Some(hash) => hash.to_base64().serialize(s),
+        None => "".serialize(s),
+    }
+}
+
+pub fn deserialize_hash<'de, D>(deserializer: D) -> Result<Option<HashType>, D::Error>
+where
+    D: serde::Deserializer<'de>,
+{
+    let hash_str = String::deserialize(deserializer)?;
+    if hash_str.is_empty() {
+        Ok(None)
+    } else {
+        Ok(Some(HashType::from_base64(&hash_str).unwrap()))
+    }
+}
+
 impl FileItem {
     /// Create a new file item from a path and initialize properties from serialization
     pub fn new(
@@ -182,20 +209,6 @@ impl FileItem {
         self.hash = Some(hash);
     }
 
-    /// Set the image hash from an encoded hash
-    pub fn set_encoded_hash(&mut self, encoded_hash: &str) {
-        self.hash = process_encoded_hash(encoded_hash);
-    }
-
-    /// Gets the image hash as an encoded hash
-    pub fn get_encoded_hash(&self) -> String {
-        if let Some(hash) = self.hash.clone() {
-            hash.to_base64()
-        } else {
-            String::new()
-        }
-    }
-
     /// Check if the file item has a hash
     pub fn has_hash(&self) -> bool {
         self.hash.is_some()
